@@ -79,6 +79,7 @@ def to_volto13(context):  # noqa: C901
         for block in blocks.values():
             if block.get("@type", "") != "listing":
                 continue
+            # fix template
             if block.get("template", False) and not block.get(
                 "variation", False
             ):
@@ -94,7 +95,10 @@ def to_volto13(context):  # noqa: C901
                 # Creates if it is not created
                 block["querystring"] = {}
             if block.get("query", False) or block.get("query") == []:
-                block["querystring"]["query"] = block["query"]
+                if not block["querystring"].get("query", []):
+                    # first time.
+                    # there is a bug in volto that re-creates block['query']
+                    block["querystring"]["query"] = block["query"]
                 del block["query"]
             if block.get("sort_on", False):
                 block["querystring"]["sort_on"] = block["sort_on"]
@@ -120,6 +124,9 @@ def to_volto13(context):  # noqa: C901
             if block.get("batch_size", False):
                 block["querystring"]["batch_size"] = block["batch_size"]
                 del block["batch_size"]
+            if block.get("b_size", False):
+                block["querystring"]["b_size"] = block["b_size"]
+                del block["b_size"]
             if block.get("depth", False):
                 block["querystring"]["depth"] = block["depth"]
                 del block["depth"]
@@ -131,6 +138,106 @@ def to_volto13(context):  # noqa: C901
                 ]
                 del block["querystring"]["batch_size"]
 
+            # fix linkMore
+            if "linkMore" in block:
+                block["linkTitle"] = block["linkMore"].get("title", "")
+                href = block["linkMore"].get("href", "")
+                item = api.content.get(href)
+                if item:
+                    block["linkHref"] = [
+                        {
+                            "@id": href,
+                            "Description": item.Description(),
+                            "Title": item.Title(),
+                            "title": item.Title(),
+                        }
+                    ]
+                else:
+                    block["linkHref"] = [{"@id": href, "title": href}]
+                del block["linkMore"]
+                logger.info(" - [LINKMORE] {}".format(url))
+
+    # fix root
+    portal = api.portal.get()
+
+    portal_blocks = getattr(portal, "blocks", "")
+    if portal_blocks:
+        portal_blocks = json.loads(portal_blocks)
+        fix_listing(portal_blocks, portal.absolute_url())
+        portal.blocks = json.dumps(portal_blocks)
+
+    # fix blocks in contents
+    pc = api.portal.get_tool(name="portal_catalog")
+    brains = pc()
+    tot = len(brains)
+    i = 0
+    for brain in brains:
+        i += 1
+        if i % 1000 == 0:
+            logger.info("Progress: {}/{}".format(i, tot))
+        item = aq_base(brain.getObject())
+        if getattr(item, "blocks", {}):
+            blocks = deepcopy(item.blocks)
+            if blocks:
+                fix_listing(blocks, brain.getURL())
+                item.blocks = blocks
+        for schema in iterSchemata(item):
+            # fix blocks in blocksfields
+            for name, field in getFields(schema).items():
+                if name == "blocks":
+                    blocks = deepcopy(item.blocks)
+                    if blocks:
+                        fix_listing(blocks, brain.getURL())
+                        item.blocks = blocks
+                else:
+                    if not HAS_BLOCKSFIELD:
+                        # blocks are only in blocks field
+                        continue
+                    if isinstance(field, BlocksField):
+                        value = deepcopy(field.get(item))
+                        if not value:
+                            continue
+                        if isinstance(value, str):
+                            if value == "":
+                                setattr(
+                                    item,
+                                    name,
+                                    {
+                                        "blocks": {},
+                                        "blocks_layout": {"items": []},
+                                    },
+                                )
+                                continue
+                        try:
+                            blocks = value.get("blocks", {})
+                        except AttributeError:
+                            logger.warning(
+                                "[RICHTEXT] - {} (not converted)".format(
+                                    brain.getURL()
+                                )
+                            )
+                        if blocks:
+                            fix_listing(blocks, brain.getURL())
+                            setattr(item, name, value)
+
+
+def to_volto13_bis(context):  # noqa: C901
+    # convert listing blocks with new standard
+
+    logger.info("### START FIXING B_SIZE ###")
+
+    def fix_listing(blocks, url):
+        for block in blocks.values():
+            if block.get("@type", "") != "listing":
+                continue
+            # fix template
+            if not block.get("b_size", False):
+                continue
+            if block.get("b_size", False):
+                block["querystring"]["b_size"] = block["b_size"]
+                del block["b_size"]
+            logger.info("- {}".format(url))
+
     # fix root
     portal = api.portal.get()
 
